@@ -7,74 +7,77 @@ use lib '../blib/lib', '../blib/arch';
 use strict;
 use Algorithm::BitVector;
 
-
-# Construct an EMPTY bit vector (a bit vector of size 0):
-print "\nConstructing an EMPTY bit vector (a bit vector of size 0):\n";
+# Construct an EMPTY bitvector (a bitvector of size 0):
+print "\nConstructing an EMPTY bitvector (a bitvector of size 0):\n";
 my $bv1 = Algorithm::BitVector->new( size => 0 );
 print "$bv1\n";                                   # no output
 
-# Construct a bit vector of size 2:
-print "\nConstructing a bit vector of size 2:\n";
+# Construct a bitvector of size 2:
+print "\nConstructing a bitvector of size 2:\n";
 my $bv2 = Algorithm::BitVector->new( size => 2 );
 print "$bv2\n";                                   # 00
 
-# Joining two bit vectors:
-print "\nConcatenating two previously constructed bit vectors:\n";
+# Joining two bitvectors:
+print "\nConcatenating two previously constructed bitvectors:\n";
 my $result = $bv1 + $bv2;
 print "$result\n";                                # 00
 
-# Construct a bit vector with a list of bits:    
-print "\nConstructing a bit vector from a list of bits:\n";
+# The following works because Perl implicitly first stringyfies each
+# argument before invoking the `.' operator
+$result = $bv1 . $bv2;
+print "$result\n";                                # 00
+
+# Construct a bitvector with a list of bits:    
+print "\nConstructing a bitvector from a list of bits:\n";
 my $bv = Algorithm::BitVector->new( bitlist => [1, 1, 0, 1] );
 print "$bv\n";                                    # 1101
 
-# Construct a bit vector from an integer
+# Construct a bitvector from an integer
 $bv = Algorithm::BitVector->new( intVal => 5678 );
-print "\nBit vector constructed from integer 5678:\n";
+print "\nbitvector constructed from integer 5678:\n";
 print "$bv\n";                                    # 1011000101110
-print "\nBit vector constructed from integer 0:\n";
+print "\nbitvector constructed from integer 0:\n";
 $bv = Algorithm::BitVector->new( intVal => 0 );
 print "$bv\n";                                    # 0
-print "\nBit vector constructed from integer 2:\n";
+print "\nbitvector constructed from integer 2:\n";
 $bv = Algorithm::BitVector->new( intVal => 2 );
 print "$bv\n";                                    # 10
-print "\nBit vector constructed from integer 3:\n";
+print "\nbitvector constructed from integer 3:\n";
 $bv = Algorithm::BitVector->new( intVal => 3 );
 print "$bv\n";                                    # 11
-print "\nBit vector constructed from integer 123456:\n";
+print "\nbitvector constructed from integer 123456:\n";
 $bv = Algorithm::BitVector->new( intVal => 123456 );
 print "$bv\n";                                    # 11110001001000000
-print "\nInt value of the previous bit vector as computed by int_value():\n";
-
+print "\nInt value of the previous bitvector as computed by int_value():\n";
 print int($bv) . "\n";                            # 123456
 
-# Construct a bit vector from a very large integer:
+# Construct a bitvector from a very large integer:
 use Math::BigInt;
 my $x = Math::BigInt->new('12345678901234567890123456789012345678901234567890');
 $bv = Algorithm::BitVector->new( intVal => $x );
-print "\nHere is a bit vector constructed from a very large integer:\n";
+print "\nHere is a bitvector constructed from a very large integer:\n";
 print "$bv\n";
-printf "The integer value of the above bit vector shown as a string is:  %s\n", $bv->int_value();
-print "Size of the bit vector: " . $bv->length() . "\n";
+printf "The integer value of the above bitvector shown as a string is:  %s\n", $bv->int_value();
+print "Size of the bitvector: " . $bv->length() . "\n";
 
-# Construct a bit vector directly from a bit string:
+# Construct a bitvector directly from a bit string:
 $bv = Algorithm::BitVector->new( bitstring => '00110011' );
-print "\nBit Vector constructed directly from a bit string:\n";
+print "\nBitvector constructed directly from a bit string:\n";
 print "$bv\n";                                    # 00110011
 $bv = Algorithm::BitVector->new( bitstring => '');
-print "\nBit Vector constructed directly from an empty bit string:\n";
+print "\nBitvector constructed directly from an empty bit string:\n";
 print "$bv\n";                                    # nothing
-print "\nInteger value of the previous bit vector:\n";
+print "\nInteger value of the previous bitvector:\n";
 print int($bv) . "\n";                            # 0
 
-# Construct a bit vector directly from an ASCII text string:
-print "\nConstructing a bit vector from the textstring 'hello':\n";
+# Construct a bitvector directly from an ASCII text string:
+print "\nConstructing a bitvector from the textstring 'hello':\n";
 my $bv3 = Algorithm::BitVector->new( textstring => "hello" );
 print "$bv3\n";              # 0110100001100101011011000110110001101111
 my $mytext = $bv3->get_text_from_bitvector();
 print "Text recovered from the previous bitvector:\n";
 print "$mytext\n";                                         # hello
-print "\nConstructing a bit vector from the textstring 'hello\\njello':\n";
+print "\nConstructing a bitvector from the textstring 'hello\\njello':\n";
 $bv3 = Algorithm::BitVector->new( textstring => "hello\njello" );
 print "$bv3\n";            
   # 0110100001100101011011000110110001101111000010100110101001100101011011000110110001101111
@@ -83,15 +86,15 @@ print "Text recovered from the previous bitvector:\n";
 print "$mytext\n";                                         # hello
                                                            # jello
 
-# Construct a bit vector directly from a hex string:
-print "\nConstructing a bit vector from the hexstring '68656c6c6f':\n";
+# Construct a bitvector directly from a hex string:
+print "\nConstructing a bitvector from the hexstring '68656c6c6f':\n";
 my $bv4 = Algorithm::BitVector->new( hexstring => "68656c6c6f" );
 print "$bv4\n";             # 0110100001100101011011000110110001101111
 my $myhexstring = $bv4->get_hex_string_from_bitvector();
 print "Hex string recovered from the previous bitvector: \n";
 print "$myhexstring\n";                                    # 68656c6c6f
 
-# Test get_bit() based array-like indexing for a bit vector:
+# Test get_bit() based array-like indexing for a bitvector:
 $bv = Algorithm::BitVector->new( bitstring => '10111' );
 print "\nPrints out bits individually from bitstring 10111:\n";
 print $bv->get_bit(0), $bv->get_bit(1), $bv->get_bit(2), $bv->get_bit(3), $bv->get_bit(4), "\n";      # 10111
@@ -145,8 +148,8 @@ print "$bv7\n";                                        # 0000000000000000000
 $bv7 = $bv5 | $bv6;
 print "$bv7\n";                                        # 1111111111111111111
 
-# Experiment with logical operations on bit vectors of different sizes:
-print "\nTry logical operations on bit vectors of different sizes:\n";
+# Experiment with logical operations on bitvectors of different sizes:
+print "\nTry logical operations on bitvectors of different sizes:\n";
 $bv = Algorithm::BitVector->new(intVal=>6) ^ Algorithm::BitVector->new(intVal=>13);
 print "$bv\n";                                         # 1011
 $bv = Algorithm::BitVector->new(intVal=>6) & Algorithm::BitVector->new(intVal=>13);
@@ -168,8 +171,8 @@ print length($bv7) . "\n";                             # 19
 my $bv8 = ($bv5 & $bv6) ^ $bv7;
 print "$bv8\n";                                        # 1111111011111111111
 
-# Constructing a bit vector from the contents of a disk file:
-print "\nConstruct a bit vector from what is in the file testinput1.txt:\n";
+# Constructing a bitvector from the contents of a disk file:
+print "\nConstruct a bitvector from what is in the file testinput1.txt:\n";
 $bv = Algorithm::BitVector->new( filename => 'testinput.txt' );
 #print "$bv\n";                                         # nothing to show
 $bv1 = $bv->read_bits_from_file(64);
@@ -180,34 +183,34 @@ print "\nRead the next 64 bits from the same file:\n";
 $bv2 = $bv->read_bits_from_file(64);
 print "$bv2\n";               
           # 0010000001100010011100100110111101110111011011100010000001100110
-print "\nTake xor of the previous two bit vectors:\n";
+print "\nTake xor of the previous two bitvectors:\n";
 $bv3 = $bv1 ^ $bv2;
 print "$bv3\n";                
           # 0110000101000010000110100001101000011001000010010101001000011111
 
-# Dividing an even-sized bit vector into two bit vectors:
+# Dividing an even-sized bitvector into two bitvectors:
 print "\nExperiment with dividing an even-sized vector into two:\n";
 ($bv4,$bv5) = $bv3->divide_into_two();
 print "$bv4\n";                           # 01100001010000100001101000011010
 print "$bv5\n";                           # 00011001000010010101001000011111
 
-# Permute a bit vector:
-print "\nWe will use this bit vector for experiments with permute()\n";
+# Permute a bitvector:
+print "\nWe will use this bitvector for experiments with permute()\n";
 $bv1 = Algorithm::BitVector->new( bitlist => [1, 0, 0, 1, 1, 0, 1] );
 print "$bv1\n";                                        # 1001101
 $bv2 = $bv1->permute( [6, 2, 0, 1] );
-print "Permuted and contracted form of the previous bit vector:\n";
+print "Permuted and contracted form of the previous bitvector:\n";
 print "$bv2\n";                                        # 1010
 
-# Write an internally generated bit vector to a disk file:
-print "\nExperiment with writing an internally generated bit vector out to a disk file:\n";
+# Write an internally generated bitvector to a disk file:
+print "\nExperiment with writing an internally generated bitvector out to a disk file:\n";
 $bv1 = Algorithm::BitVector->new( bitstring => '00001010' ); 
 open my $FILEOUT, ">test.txt";
 $bv1->write_to_file( $FILEOUT );
 close $FILEOUT;
 $bv2 = Algorithm::BitVector->new( filename => 'test.txt' );
 $bv3 = $bv2->read_bits_from_file( 32 );
-print "\nDisplay bit vectors written out to file and read back from the file and their respective lengths:\n";
+print "\nDisplay bitvectors written out to file and read back from the file and their respective lengths:\n";
 print "$bv1      $bv3\n";                                      #   00001010      00001010
 print length($bv1) . "             " . length($bv3) . "\n";    #   8             8
 
@@ -221,21 +224,20 @@ while ($bv->{more_to_read}) {
     print "$bv_read\n";
 }
 print "\n";
-                    # 0100000100100000011010000111010101101110011001110111001001111001
-                    # 0010000001100010011100100110111101110111011011100010000001100110
-                    # 0110111101111000001000000110101001110101011011010111000001100101
-                    # 0110010000100000011011110111011001100101011100100010000001100001
-                    # 0010000001101100011000010111101001111001001000000111011101101001
-                    # 0110110001100100001000000110010001101111011001110010111000001010
-                    # 0000101001100001011000010110000101100001011000010110000101100001
-                    # 0110000101100001011000010110000101100001000010100000101001101010
-                    # 0110101001101010011010100110101001101010011010100110101001101010
-                    # 0110101001101010011010100110101001101010011010100110101001101010
-                    # 0000101000001010011000110111001001111001011100000111010001101111
-                    # 0010000001110100011001010110101100001010
+                  # 0100000100100000011010000111010101101110011001110111001001111001
+                  # 0010000001100010011100100110111101110111011011100010000001100110
+                  # 0110111101111000001000000110101001110101011011010111000001100101
+                  # 0110010000100000011011110111011001100101011100100010000001100001
+                  # 0010000001101100011000010111101001111001001000000111011101101001
+                  # 0110110001100100001000000110010001101111011001110010111000001010
+                  # 0000101001100001011000010110000101100001011000010110000101100001
+                  # 0110000101100001011000010110000101100001000010100000101001101010
+                  # 0110101001101010011010100110101001101010011010100110101001101010
+                  # 0110101001101010011010100110101001101010011010100110101001101010
+                  # 0000101000001010
 
-print "\nExperiment with closing a file object and start extracting bit vectors from the file from the beginning again:\n";
-$bv->close_file_object();
+print "\nExperiment with closing a file object and start extracting bitvectors from the file from the beginning again:\n";
+$bv->close_file_handle();
 $bv = Algorithm::BitVector->new( filename => 'testinput.txt' );
 $bv1 = $bv->read_bits_from_file(64);
 print "Here are all the first 64 bits read from the file again after the file object was closed and opened again:\n";
@@ -253,7 +255,7 @@ $bv2 = $bv1->permute( [22, 47, 33, 36, 18, 6, 32, 29, 54, 62, 4,
                        10, 57, 12, 30, 3, 52, 11, 26, 43, 21, 13,
                        58, 37, 48, 28, 1, 63, 2, 31, 53, 56, 44, 24,
                        51, 19, 7, 5, 34, 27, 16, 46] );
-print "Permuted bit vector:\n";
+print "Permuted bitvector:\n";
 print "$bv2\n";      # 0111100110001011010111000100100111100000100011001101000010101101
 $bv3 = $bv2->unpermute( [22, 47, 33, 36, 18, 6, 32, 29, 54, 62, 4,
                           9, 42, 39, 45, 59, 8, 50, 35, 20, 25, 49,
@@ -261,13 +263,11 @@ $bv3 = $bv2->unpermute( [22, 47, 33, 36, 18, 6, 32, 29, 54, 62, 4,
                          10, 57, 12, 30, 3, 52, 11, 26, 43, 21, 13,
                          58, 37, 48, 28, 1, 63, 2, 31, 53, 56, 44, 24,
                          51, 19, 7, 5, 34, 27, 16, 46] );    
-print "Result obtained by unpurmuting the permuted bit vector:\n";
+print "Result obtained by unpurmuting the permuted bitvector:\n";
 print "$bv3\n";      # 0100000100100000011010000111010101101110011001110111001001111001
 
-#no warnings "void";
-
 # Experiments with circular shifts to the left and to the right:
-print "\nTry circular shifts to the left and to the right for the following bit vector:\n";
+print "\nTry circular shifts to the left and to the right for the following bitvector:\n";
 print "$bv3\n";      # 0100000100100000011010000111010101101110011001110111001001111001
 print "Circular shift to the left by 7 positions:\n";
 $bv3 = $bv3 << 7;
@@ -275,25 +275,25 @@ print "$bv3\n";      # 100100000011010000111010101101110011001110111001001111001
 print "\nCircular shift to the right by 7 positions:\n";
 $bv3 = $bv3 >> 7;
 print "$bv3\n";      # 0100000100100000011010000111010101101110011001110111001001111001
-print "Test length on the above bit vector:   ";
+print "Test length on the above bitvector:   ";
 print length($bv3) . "\n";                      # 64
 
 print "\nExperiments with chained invocations of circular shifts:\n";
-$bv = Algorithm::BitVector->new( bitlist => [1,1, 1, 0, 0, 1] );
-print "$bv\n";
+$bv = Algorithm::BitVector->new( bitlist => [1, 1, 1, 0, 0, 1] );
+print "$bv\n";                                    # 111001
 $bv = $bv >> 1;
-print "$bv\n";
+print "$bv\n";                                    # 111100
 $bv = $bv >> 1 >> 1;
-print "$bv\n";
-$bv = Algorithm::BitVector->new( bitlist => [1,1, 1, 0, 0, 1] );
-print "$bv\n";
+print "$bv\n";                                    # 001111
+$bv = Algorithm::BitVector->new( bitlist => [1, 1, 1, 0, 0, 1] );
+print "$bv\n";                                    # 111001
 $bv = $bv << 1;
-print "$bv\n";
+print "$bv\n";                                    # 110011
 $bv = $bv << 1 << 1;
-print "$bv\n";
+print "$bv\n";                                    # 001111
 
-# Experiment with extracting a slice of a bit vector:
-print "\nTest forming a [5..21] slice of the above bit vector:\n";
+# Experiment with extracting a slice of a bitvector:
+print "\nTest forming a [5..21] slice of the above bitvector:\n";
 # The following call will return bits indexed from 5 through 21 from the $bv3 
 # bitvector:
 my $arr = $bv3->get_bit([5..21]);
@@ -306,17 +306,17 @@ while (<$bv4>) {
 }          # 0 1 1 0 0 0 0 1 0 1 0 0 0 0 1 0 0 0 0 1 1 0 1 0 0 0 0 1 1 0 1 0
 print "\n";
 
-# Experiments with padding a bit vector with zeros:
-print "\nDemonstrate padding a bit vector from left:\n";
+# Experiments with padding a bitvector with zeros:
+print "\nDemonstrate padding a bitvector from left:\n";
 $bv = Algorithm::BitVector->new( bitstring => '101010' );
 $bv->pad_from_left( 4 );
 print "$bv\n";                           # 000010101
-print "\nDemonstrate padding a bit vector from right:\n";
+print "\nDemonstrate padding a bitvector from right:\n";
 $bv->pad_from_right( 4 );
 print "$bv\n";                           # 00001010100000
 
-# Experiments with the size modifier when int value is used for constructing a bit vector:
-print "\nTest the size modifier when a bit vector is initialized with the intVal method:\n";
+# Experiments with the size modifier when int value is used for constructing a bitvector:
+print "\nTest the size modifier when a bitvector is initialized with the intVal method:\n";
 $bv = Algorithm::BitVector->new( intVal => 45, size => 16 );
 print "$bv\n";                           # 0000000000101101
 $bv = Algorithm::BitVector->new( intVal => 0, size => 8 );
@@ -324,7 +324,7 @@ print "$bv\n";                           # 00000000
 $bv = Algorithm::BitVector->new( intVal => 1, size => 8 );    
 print "$bv\n";                           # 00000001
 
-# Experiments with resetting a bit vector to either all 1's or all 0's:
+# Experiments with resetting a bitvector to either all 1's or all 0's:
 print "\nTesting reset method:\n";
 $bv1->reset(1);             
 print "$bv1\n";     
@@ -344,7 +344,7 @@ print $bv->count_bits() . "\n";                 # 1
 $bv = Algorithm::BitVector->new( bitstring => '00000000000000' );
 print $bv->count_bits() . "\n";                 # 0
 
-# Experiment with the fast algorithm for counts the set bits in large but sparse bit vectors:
+# Experiment with the fast algorithm for counts the set bits in large but sparse bitvectors:
 print "\nTesting count_bits_sparse() on a vector of TWO MILLION bits (be patient):\n";
 $bv = Algorithm::BitVector->new( size => 2000000 );
 $bv->set_bit(345234, 1);
@@ -354,7 +354,7 @@ $bv->set_bit(18, 1);
 $bv->set_bit(785, 1);
 print "The number of bits set: " . $bv->count_bits_sparse() . "\n";  # 5
 
-# Experiments with resetting the internals of a bit vector:
+# Experiments with resetting the internals of a bitvector:
 print "\nTest set_value() method:\n";
 $bv = Algorithm::BitVector->new( intVal => 7, size => 16 );
 print "$bv\n";                             # 0000000000000111
@@ -385,7 +385,7 @@ print "\nTesting rank_of_bit_set_at_index():\n";
 $bv = Algorithm::BitVector->new( bitstring => '01010101011100' );
 print $bv->rank_of_bit_set_at_index( 10 ) . "\n";                 # 6
 
-# Experiment with determining whether the int value of a bit vector is a power 2:
+# Experiment with determining whether the int value of a bitvector is a power 2:
 print "\nTesting is_power_of_2():\n";
 $bv = Algorithm::BitVector->new( bitstring => '10000000001110' );
 print "int value: " . int($bv) . "\n";                       # 826
@@ -393,13 +393,13 @@ print $bv->is_power_of_2() . "\n";                            # 0
 print "\nTesting is_power_of_2_sparse():\n";             
 print $bv->is_power_of_2_sparse() . "\n";                      # 0
 
-# Experiment with reversing a bit vector:
+# Experiment with reversing a bitvector:
 print "\nTesting reverse():\n";
 $bv = Algorithm::BitVector->new( bitstring => '0001100000000000001' );
 print "original bv: $bv\n";                      # 0001100000000000001
 print "reversed bv: " . $bv->reverse() . "\n";   # 1000000000000011000
 
-# Calculate the GCD of two bit vectors using Euclid's algorithm on the integers values:
+# Calculate the GCD of two bitvectors using Euclid's algorithm on the integers values:
 print "\nTesting Greatest Common Divisor (gcd):\n";
 $bv1 = Algorithm::BitVector->new( bitstring => '01100110' );
 print "first arg bv: $bv1 of int value: " . int($bv1) . "\n";    #102
@@ -408,7 +408,7 @@ print "second arg bv: $bv2 of int value: "  . int($bv2) . "\n";  # 26
 $bv = $bv1->gcd( $bv2 );
 print "gcd bitvec is: $bv of int value: " . int($bv) . "\n";     # 2
 
-# Calculate the multiplicative inverse of a bit vector with respect to a modulus vector:
+# Calculate the multiplicative inverse of a bitvector with respect to a modulus vector:
 print "\nTesting multiplicative_inverse:\n";
 my $bv_modulus = Algorithm::BitVector->new( intVal => 32 );
 print "modulus is bitvec: $bv_modulus of int value: " . int($bv_modulus) . "\n";
@@ -521,28 +521,27 @@ print "@products\n";
 print "\nExperimenting with runs():\n";
 $bv = Algorithm::BitVector->new( bitlist => [1, 0, 0, 1] );
 my @bvruns = $bv->runs();
-print "For bit vector: $bv";
+print "For bitvector: $bv";
 print "       the runs are: @bvruns\n";
 $bv = Algorithm::BitVector->new( bitlist => [1, 0] );
 @bvruns = $bv->runs();
-print "For bit vector: $bv";
+print "For bitvector: $bv";
 print "       the runs are: @bvruns\n";
 $bv = Algorithm::BitVector->new( bitlist => [0, 1] );
 @bvruns = $bv->runs();
-print "For bit vector: $bv";
+print "For bitvector: $bv";
 print "       the runs are: @bvruns\n";
 $bv = Algorithm::BitVector->new( bitlist => [0, 0, 0, 1] );
 @bvruns = $bv->runs();
-print "For bit vector: $bv";
+print "For bitvector: $bv";
 print "       the runs are: @bvruns\n";
 $bv = Algorithm::BitVector->new( bitlist => [0, 1, 1, 0] );
 @bvruns = $bv->runs();
-print "For bit vector: $bv";
+print "For bitvector: $bv";
 print "       the runs are: @bvruns\n";
 
-#UNCOMMENT THE FOLLOWING LINES TO TEST THE
-#PRIMALITY TESTING METHOD. IT SHOULD SHOW
-#THAT ALL OF THE FOLLOWING NUMBERS ARE PRIME:
+# Experiments with primality testing of small integers:
+print "\nRun the small-integer primality test on a a bunch of known primes:\n";
 my @primes = (179, 233, 283, 353, 419, 467, 547, 607, 661, 739, 811, 877, 
               947, 1019, 1087, 1153, 1229, 1297, 1381, 1453, 1523, 1597, 
               1663, 1741, 1823, 1901, 7001, 7109, 7211, 7307, 7417, 7507,
@@ -553,6 +552,7 @@ foreach my $p (@primes) {
     print "The primality test for $p: $check\n";
 }
 
+# Experiments with random bit generation for a bitvector:
 print "\nGenerate 16-bit wide candidates for primality testing:\n";
 foreach my $i (0..10) {
     $bv = Algorithm::BitVector->new( intVal => 0 );
